import random

def associate_pair(d, key, value):
    '''(dict of {object:list}, object, object) -> NoneType
    key is immutable. Add the key-value pair to d. 
    If key occurs in d, append value to its
    list of values. Otherwise, insert this new key and make its value be a
    list of one element: [value].
    '''    
    
    if key in d:
        d[key].append(value)
    else:
        d[key] = [value]
    

def make_dictionary(f):
    '''(file) -> dict of {str:list of str}
    Return a dictionary where the keys are words in f and the value
    for a key is the list of words that were found to follow the key in f.
    '''
       
    d = {}
    context = ""
    
    for line in f:
        word_list = line.split()
        
        for word in word_list:
            # We have a word and it's context.  Remember that in the dictionary!
            associate_pair(d, context, word)
            # The current word becomes the context for the next word.
            context = word
            
    return d

def mimic_text(word_dict, num_words):
    '''(dict of {str:list of str}, int) -> str
    Based on the word patterns in word_dict, return a string that mimics
    that text, and has num_words words.    
    '''
    
    story = ""
    context = ""
    
    for i in range(num_words):
        # Choose the next word, based on context.
        follow_words = word_dict[context]        
        word = follow_words[random.randint(0, len(follow_words) - 1)]
        
        story = story + " " + word # add to story
        context = word
        
    return story        

# Read a text and remember the words and what comes after them in a dict
f = open(input("Training text: "))
d = make_dictionary(f)
print(mimic_text(d, 5))
