import random

def associate_pair(d, key, value):
    '''(dict of {object:list}, object, object) -> NoneType
    key is immutable. Add the key-value pair to d. 
    If key occurs in d, append value to its
    list of values. Otherwise, insert this new key and make its value be a
    list of one element: [value].
    '''    
    
    if key in d:
        d[key].append(value)
    else:
        d[key] = [value]
    
def random_element(lst):
    '''(list of object) -> object
    Return a random element of nonempty lst.
    '''
    
    return random.choice(lst)

def make_dictionary(f, context_length):
    '''(file, int) -> dict of {tuple of str:list of str}
    Return a dictionary where the keys are tuples of length context_length
    containing words in f and the value for a key is the list of words
    that were found to follow the key in f.
    '''
       
    d = {}
    context = ('',) * context_length
    
    for line in f:
        word_list = line.split()
        
        for word in word_list:
            # We have a word and it's context.  Remember that in the dictionary!
            associate_pair(d, context, word)
            # Roll the context forward.
            context = context[1:] + (word,)
    
    return d

def mimic_text(word_dict, num_words, context_length):
    '''(dict of {tuple of str:list of str}, int, int) -> str
    Based on the word patterns in word_dict, return a string that mimics
    that text, and has num_words words. context_length
    is the length of the tuples in word_dict.
    '''
    
    story = ""
    context = random_element(list(word_dict.keys()))
    
    for i in range(num_words):
        # Choose the next word, based on context.
        if context not in d: # start at new context
            context = random_element(list(word_dict.keys()))

        word = random_element(word_dict[context])
        
        story = story + " " + word # add to story
        context = context[1:] + (word,)
        
    return story
        

# Read a text and remember the words and what comes after them in a dict.
f = open(input("Training text: "))
context_length = int(input("Words of context: "))
d = make_dictionary(f, context_length)
print(mimic_text(d, 500, context_length))
    