class Rational(object):
    '''Rational numbers'''

    def __init__(self, numer, denom):
        '''(int, int) -> Rational
        create Rational with given numer and denom,
        and reduce to lowest terms.
        '''
        if numer < 0 and denom >= 0:
            numer = -numer
            denom = -denom
        self._numer = numer
        self._denom = denom
        self._reduce()

    def numerator(self):
        '''() -> int
        Return the numerator.
        '''
        return self._numer
  
    def denominator(self):
        '''() -> int
        Return the denominator.
        '''
        return self._denom
   
    def __str__(self):
        '''() -> str
        Return the string representation of the Rational.
        '''
        return str(self._numer) + '/' + str(self._denom)

    def _reduce(self):
        '''() -> NoneType
        Reduce the Rational to lowest terms.
        '''
        divisor = self._gcd(self._numer, self._denom)
        self._numer = self._numer // divisor
        self._denom = self._denom // divisor

    def _gcd(self, a, b):
        '''(int, int) -> int
        Return greatest common divisor of a and b.
        '''
        (a, b) = (max(a, b), min(a, b))
        while b != 0:
            (a, b) = (b, a % b)
        return a

    # Methods for arithmetic and comparisons go here

    def __add__(self, other):
        '''(Rational) -> Rational
        Return the sum of this Rational and other.
        '''
        newNumer = self._numer * other._denom + \
                   other._numer * self._denom
        newDenom = self._denom * other._denom
        return Rational(newNumer, newDenom)

    def __lt__(self, other):
        '''(Rational) -> bool
        Return True iff this Rational is less than other.
        '''
        extremes = self._numer * other._denom
        means = other._numer * self._denom
        return extremes < means

    def __eq__(self, other):
        '''(Rational) -> bool
        Return True iff this Rational equals other.
        '''
        if self is other: 
            return True
        elif type(self) != type(other):
            return False
        else:
            return self._numer == other._numer and \
                   self._denom == other._denom
