class SavingsAccount(object):
    '''Savings accounts with owner's name, PIN, and balance.'''
    
    RATE = 0.02
        
    def __init__(self, name, pin, balance = 0.0):
        '''(str, str, int) -> SavingsAccount
        Create SavingsAccount with given name, pin, and balance.
        '''
        self._name = name
        self._pin = pin
        self._balance = balance

    def __str__(self):
        '''() -> str
        Return string representation of SavingsAccount.
        '''
        result =  'Name:    ' + self._name + '\n' 
        result += 'PIN:     ' + self._pin + '\n' 
        result += 'Balance: ' + str(self._balance)
        return result

    def getBalance(self):
        '''() -> int
        Return balance of this SavingsAccount.
        '''
        return self._balance

    def getName(self):
        '''() -> str
        Return name of this SavingsAccount.
        '''
        return self._name

    def getPin(self):
        '''() -> int
        Return PIN of this SavingsAccount.
        '''
        return self._pin

    def deposit(self, amount):
        '''(int) -> int
        Deposit the given amount and return the new balance.
        '''
        self._balance += amount
        return self._balance

    def withdraw(self, amount):
        '''(int) -> str or NoneType
        Withdraw the given amount. Return None if successful,
        or an error message if unsuccessful.
        '''
        if amount < 0:
            return 'Amount must be >= 0'
        elif self._balance < amount:
            return 'Insufficient funds'
        else:
            self._balance -= amount
            return None

    def computeInterest(self):
        '''() -> int
        Compute, deposit, and return the interest.
        '''
        interest = self._balance * SavingsAccount.RATE
        self.deposit(interest)
        return interest

